@@ -81,11 +81,11 @@ override('do_layout', sub {
         }
 
         # Keep up with the tallest component we find
-        if($comp_height > $lines[$line]->{tallest}) {
+        if(!($lines[$line]->{tallest}) || $comp_height > $lines[$line]->{tallest}) {
             $lines[$line]->{tallest} = $comp_height;
         }
         # Keep up with the widest component we find
-        if($comp_width > $lines[$line]->{widest}) {
+        if(!($lines[$line]->{widest}) || $comp_width > $lines[$line]->{widest}) {
             $lines[$line]->{widest} = $comp_width;
         }
 
@@ -129,6 +129,7 @@ override('do_layout', sub {
                 $co->y($oy + $yused);
 
                 $line++;
+
                 $lines[$line]->{width} = $ox + $comp_width;
                 $lines[$line]->{tallest} = $comp_height;
             } else {
@@ -242,12 +243,11 @@ future if they are needed.
 
 =head1 SYNOPSIS
 
-  my $lm = Layout::Manager::Flow->new(anchor => 'north');
-  
-  $lm->add_component($comp1);
-  $lm->add_component($comp2);
+  $cont->add_component($comp1);
+  $cont->add_component($comp2);
 
-  $lm->do_layout($container);
+  my $lm = Layout::Manager::Flow->new(anchor => 'north');
+  $lm->do_layout($cont);
 
 =head1 ATTRIBUTES
 
