@@ -53,46 +53,25 @@ basically stacks them all vertically.
 
 =head1 SYNOPSIS
 
-  my $lm = Layout::Manager::Single->new();
-  
-  $lm->add_component($comp1);
-  $lm->add_component($comp2);
+  $cont->add_component($comp1);
+  $cont->add_component($comp2);
 
-  $lm->do_layout($container);
+  my $lm = Layout::Manager::Single->new();
+  $lm->do_layout($cont);
 
 =head1 METHODS
 
-=head2 Constructor
-
-=over 4
-
-=item I<new>
-
-Creates a new Layout::Manager::Single.
-
-=back
-
-=head2 Instance Methods
-
-=over 4
-
-=item I<do_layout>
+=head2 do_layout
 
 Size and position the components in this layout.
 
-=back
-
 =head1 AUTHOR
 
 Cory Watson, C<< <gphat@cpan.org> >>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008 - 2010 by Cory G Watson
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
\ No newline at end of file
